# coding: utf-8
import inspect
import os
from ctypes import *

import pkg_resources

libc = CDLL(pkg_resources.resource_filename('fix_utcnow', 'c/libfixutcnow.so'))
_fix_utcnow = libc.utcnow
_fix_utcnow.restype = c_char_p


def fix_utcnow():
    return _fix_utcnow().decode()




import os

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


config = {
    'description': 'fix-utcnow',
    'author': 'Maksim Afanasevsky',
    'url': 'https://github.com/maxtwen/fix-utcnow',
    'download_url': 'https://github.com/maxtwen/fix-utcnow',
    'author_email': 'maxtwen1@gmail.com',
    'version': '0.4',
    'install_requires': [''],
    'packages': ['fix_utcnow'],
    'scripts': [],
    'name': 'fix_utcnow',
    'data_files': [('fix_utcnow/c', ['fix_utcnow/c/libfixutcnow.so'])]
    # 'long_description': read('README.md'),
    # 'long_description_content_type': 'text/markdown'
}

setup(**config)
